import { QueryKey, Client, QueryOptions, Query } from './chunk-7AQUOPJQ.js';
import { createReactGenerator } from '@kubb/plugin-oas';
import { useOperationManager } from '@kubb/plugin-oas/hooks';
import { pluginTsName } from '@kubb/plugin-ts';
import { pluginZodName } from '@kubb/plugin-zod';
import { useApp, File } from '@kubb/react';
import { difference } from 'remeda';
import { jsxs, jsx, Fragment } from '@kubb/react/jsx-runtime';

var queryGenerator = createReactGenerator({
  name: "svelte-query",
  Operation({ options, operation }) {
    const {
      plugin: {
        options: { output }
      }
    } = useApp();
    const { getSchemas, getName, getFile } = useOperationManager();
    const isQuery = typeof options.query === "boolean" ? true : options.query?.methods.some((method) => operation.method === method);
    const isMutation = difference(["post", "put", "delete", "patch"], options.query ? options.query.methods : []).some((method) => operation.method === method);
    const importPath = options.query ? options.query.importPath : "@tanstack/solid-query";
    const query = {
      name: getName(operation, { type: "function", prefix: "create" }),
      typeName: getName(operation, { type: "type" }),
      file: getFile(operation, { prefix: "create" })
    };
    const client = {
      name: getName(operation, { type: "function" })
    };
    const queryOptions = {
      name: getName(operation, { type: "function", suffix: "QueryOptions" })
    };
    const queryKey = {
      name: getName(operation, { type: "const", suffix: "QueryKey" }),
      typeName: getName(operation, { type: "type", suffix: "QueryKey" })
    };
    const type = {
      file: getFile(operation, { pluginKey: [pluginTsName] }),
      //todo remove type?
      schemas: getSchemas(operation, { pluginKey: [pluginTsName], type: "type" })
    };
    const zod = {
      file: getFile(operation, { pluginKey: [pluginZodName] }),
      schemas: getSchemas(operation, { pluginKey: [pluginZodName], type: "function" })
    };
    if (!isQuery || isMutation) {
      return null;
    }
    return /* @__PURE__ */ jsxs(File, { baseName: query.file.baseName, path: query.file.path, meta: query.file.meta, banner: output?.banner, footer: output?.footer, children: [
      options.parser === "zod" && /* @__PURE__ */ jsx(File.Import, { name: [zod.schemas.response.name], root: query.file.path, path: zod.file.path }),
      /* @__PURE__ */ jsx(File.Import, { name: "client", path: options.client.importPath }),
      /* @__PURE__ */ jsx(File.Import, { name: ["RequestConfig"], path: options.client.importPath, isTypeOnly: true }),
      options.client.dataReturnType === "full" && /* @__PURE__ */ jsx(File.Import, { name: ["ResponseConfig"], path: options.client.importPath, isTypeOnly: true }),
      /* @__PURE__ */ jsx(
        File.Import,
        {
          name: [
            type.schemas.request?.name,
            type.schemas.response.name,
            type.schemas.pathParams?.name,
            type.schemas.queryParams?.name,
            type.schemas.headerParams?.name,
            ...type.schemas.statusCodes?.map((item) => item.name) || []
          ].filter(Boolean),
          root: query.file.path,
          path: type.file.path,
          isTypeOnly: true
        }
      ),
      /* @__PURE__ */ jsx(
        QueryKey,
        {
          name: queryKey.name,
          typeName: queryKey.typeName,
          operation,
          paramsCasing: options.paramsCasing,
          pathParamsType: options.pathParamsType,
          typeSchemas: type.schemas,
          transformer: options.queryKey
        }
      ),
      /* @__PURE__ */ jsx(
        Client,
        {
          name: client.name,
          isExportable: false,
          isIndexable: false,
          baseURL: options.client.baseURL,
          operation,
          typeSchemas: type.schemas,
          zodSchemas: zod.schemas,
          dataReturnType: options.client.dataReturnType,
          paramsCasing: options.paramsCasing,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType,
          parser: options.parser
        }
      ),
      /* @__PURE__ */ jsx(File.Import, { name: ["queryOptions"], path: importPath }),
      /* @__PURE__ */ jsx(
        QueryOptions,
        {
          name: queryOptions.name,
          clientName: client.name,
          queryKeyName: queryKey.name,
          typeSchemas: type.schemas,
          paramsCasing: options.paramsCasing,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType
        }
      ),
      options.query && /* @__PURE__ */ jsxs(Fragment, { children: [
        /* @__PURE__ */ jsx(File.Import, { name: ["createQuery"], path: importPath }),
        /* @__PURE__ */ jsx(File.Import, { name: ["QueryKey", "CreateBaseQueryOptions", "CreateQueryResult"], path: importPath, isTypeOnly: true }),
        /* @__PURE__ */ jsx(
          Query,
          {
            name: query.name,
            queryOptionsName: queryOptions.name,
            typeSchemas: type.schemas,
            paramsType: options.paramsType,
            pathParamsType: options.pathParamsType,
            operation,
            paramsCasing: options.paramsCasing,
            dataReturnType: options.client.dataReturnType,
            queryKeyName: queryKey.name,
            queryKeyTypeName: queryKey.typeName
          }
        )
      ] })
    ] });
  }
});

export { queryGenerator };
//# sourceMappingURL=chunk-5WJYHFK6.js.map
//# sourceMappingURL=chunk-5WJYHFK6.js.map